@@ -11,9 +11,9 @@ use base qw(Exporter);
 
 my @controlcifers = qw(2 1 2 1 2 1 2 1 2 1 2 1 2 1 2 1);
 
-$VERSION = '0.07';
-@EXPORT_OK
-    = qw(calculate validate validatePO _argument _content _length _calculate_sum);
+$VERSION = '0.08';
+@EXPORT_OK =
+  qw(calculate validate validatePO _argument _content _length _calculate_sum);
 
 use constant CONTROLCODE_LENGTH => 16;
 use constant INVOICE_MINLENGTH  => 1;
@@ -69,7 +69,8 @@ sub validate {
 
     if ( $sum % MODULUS_OPERAND ) {
         return 0;
-    } else {
+    }
+    else {
         return 1;
     }
 }
@@ -79,11 +80,13 @@ sub _argument {
 
     if ($maxlen) {
         croak
-            "function takes an argument of minimum: $length and maximum $maxlen digits";
+"function takes an argument of minimum: $length and maximum $maxlen digits";
 
-    } elsif ($length) {
+    }
+    elsif ($length) {
         croak "function takes an argument of $length digits";
-    } else {
+    }
+    else {
         croak "function takes an argument";
     }
 }
@@ -104,12 +107,13 @@ sub _length {
         if ( length($number) < $length ) {
             croak "argument: $number has to be $length digits long";
 
-        } elsif ( length($number) > $maxlen ) {
-            croak
-                "argument: $number must be not more than $maxlen digits long";
+        }
+        elsif ( length($number) > $maxlen ) {
+            croak "argument: $number must be not more than $maxlen digits long";
         }
 
-    } else {
+    }
+    else {
         if ( length($number) != $length ) {
             croak "argument: $number has to be $length digits long";
         }
@@ -123,7 +127,7 @@ sub _calculate_sum {
     my $sum = 0;
     my @numbers = split( //, $number );
 
-    for ( my $i = 0; $i < scalar(@numbers); $i++ ) {
+    for ( my $i = 0 ; $i < scalar(@numbers) ; $i++ ) {
         my $tmpsum2 = 0;
         my $tmpsum  = $numbers[$i] * $controlcifers[$i];
 
@@ -144,9 +148,11 @@ sub _calculate_sum {
 
 __END__
 
+=pod
+
 =head1 NAME
 
-Business::DK::PO - danish postal order code generator/validator
+Business::DK::PO - Danish postal order number validator
 
 =head1 VERSION
 
@@ -197,7 +203,7 @@ This documentation describes version 0.07
 The postal orders and postal order codes are used by the danish postal service
 B<PostDanmark>.
 
-=head1 FUNCTIONS
+=head1 SUBROUTINES/METHODS
 
 =head2 validate
 
@@ -270,7 +276,7 @@ that the argument becomes a valid postal order code.
 The calculated and valid code is then returned, left-padded with zeroes to make
 it 16 digits long (SEE: validate).
 
-=head1 PRIVATE FUNCTIONS
+=head1 PRIVATE SUBROUTINES/METHODS
 
 =head2 _argument
 
